import { Button } from '@/components/ui/button';
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { Input } from '@/components/ui/input';
import { Textarea } from '@/components/ui/textarea';
import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from '@/components/ui/accordion';

export default function SupportPage() {
  return (
    <div className='container mx-auto px-4 py-8'>
      <h1 className='text-4xl font-bold mb-8'>Help & Support</h1>
      <div className='grid gap-8 md:grid-cols-2'>
        <Card>
          <CardHeader>
            <CardTitle>Frequently Asked Questions</CardTitle>
            <CardDescription>
              Find quick answers to common questions
            </CardDescription>
          </CardHeader>
          <CardContent>
            <Accordion type='single' collapsible>
              <AccordionItem value='item-1'>
                <AccordionTrigger>
                  How do I list an item for sale?
                </AccordionTrigger>
                <AccordionContent>
                  To list an item, go to the &quot;Your Listings&quot; page and
                  click on &quot;Add New Listing&quot;. Fill out the required
                  information about your item and submit the form.
                </AccordionContent>
              </AccordionItem>
              <AccordionItem value='item-2'>
                <AccordionTrigger>How can I contact a seller?</AccordionTrigger>
                <AccordionContent>
                  When viewing an item, you&apos;ll see a &quot;Contact
                  Seller&quot; button. Click on it to send a message to the
                  seller through our platform.
                </AccordionContent>
              </AccordionItem>
              <AccordionItem value='item-3'>
                <AccordionTrigger>
                  What payment methods are accepted?
                </AccordionTrigger>
                <AccordionContent>
                  We currently support payments through PayPal and major credit
                  cards. Cash transactions can be arranged for in-person
                  exchanges.
                </AccordionContent>
              </AccordionItem>
            </Accordion>
          </CardContent>
        </Card>
        <Card>
          <CardHeader>
            <CardTitle>Contact Support</CardTitle>
            <CardDescription>
              Get in touch with our support team
            </CardDescription>
          </CardHeader>
          <CardContent>
            <form className='space-y-4'>
              <div className='space-y-2'>
                <label htmlFor='name'>Name</label>
                <Input id='name' placeholder='Your name' />
              </div>
              <div className='space-y-2'>
                <label htmlFor='email'>Email</label>
                <Input
                  id='email'
                  type='email'
                  placeholder='Your email address'
                />
              </div>
              <div className='space-y-2'>
                <label htmlFor='message'>Message</label>
                <Textarea
                  id='message'
                  placeholder='Describe your issue or question'
                />
              </div>
            </form>
          </CardContent>
          <CardFooter>
            <Button>Submit</Button>
          </CardFooter>
        </Card>
      </div>
    </div>
  );
}
